@@ -9,7 +9,7 @@ from functools import lru_cache
 import requests
 from PIL import Image
 
-from ..token import Token
+from ..token import BookToken, Token
 from . import DEFAULT_DEPLOYMENT_URL
 from .request import request, request_image
 
@@ -59,13 +59,19 @@ def upload_snip(snippet: dict, token: Token, **kwargs) -> dict:
     **kwargs: Any
         Additional keyword arguments to pass to the requests.post function.
     """
+    # Update book id if not set
     if (
         "book_id" not in snippet
         or snippet["book_id"] is None
         or snippet["book_id"] <= 0
     ):
-        snippet["book_id"] = token.book_id
-    elif snippet["book_id"] != token.book_id:
+        if isinstance(token, BookToken):
+            snippet["book_id"] = token.book_id
+
+    if "book_id" not in snippet or snippet["book_id"] is None:
+        raise ValueError("Snippet book_id is required for upload!")
+
+    if isinstance(token, BookToken) and snippet["book_id"] != token.book_id:
         raise ValueError("Snippet book_id does not match token book_id!")
 
     if "data" in snippet and "snip" in snippet["data"]:
@@ -76,7 +82,7 @@ def upload_snip(snippet: dict, token: Token, **kwargs) -> dict:
 
     data = request(
         method="POST",
-        url=f"{token.deployment_url}/api/books/{token.book_id}/upload",
+        url=f"{token.deployment_url}/api/books/{snippet['book_id']}/upload",
         token=token,
         json=snippet,
         **kwargs,
