@@ -1,6 +1,6 @@
 import pytest
-from snip.token.storage import file_store, keyring_store
-from snip.token.token import Token
+from snip.token.storage import file_store, keyring_store, get_all_tokens
+from snip.token import BookToken, AccountToken
 
 
 class TestFileStore:
@@ -14,7 +14,8 @@ class TestFileStore:
         for i, token in enumerate(tokens):
             assert token.name == compare_tokens[i].name
             assert token.token == compare_tokens[i].token
-            assert token.book_id == compare_tokens[i].book_id
+            if isinstance(token, BookToken):
+                assert token.book_id == compare_tokens[i].book_id
             assert isinstance(token.deployment_url, str)
 
     def test_get_all_tokens_invalid(self, invalid_config_file, caplog):
@@ -26,10 +27,7 @@ class TestFileStore:
         assert len(sources) == len(compare_tokens)
 
         # Check that we had a logging.warning
-        assert len(caplog.records) == 1
-        assert (
-            "does not contain book_id or token. Skipping." in caplog.records[0].message
-        )
+        assert len(caplog.records) != 0
 
     def test_duplicates(self, config_file, another_config_file, caplog):
         config_file, compare_tokens = config_file
@@ -52,7 +50,8 @@ class TestFileStore:
             assert t is not None
             assert t.name == token.name
             assert t.token == token.token
-            assert t.book_id == token.book_id
+            if isinstance(t, BookToken):
+                assert t.book_id == token.book_id
             assert isinstance(t.deployment_url, str)
 
         # Test not found
@@ -87,8 +86,7 @@ class TestKeyringStore:
 
         tokens_b = keyring_store.get_all_tokens(dummy_keyring)
 
-        assert len(caplog.records) == 1
-        assert "is invalid" in caplog.records[0].message
+        assert len(caplog.records) != 0
         assert len(tokens_b) == len(tokens) - 1
 
     def test_get_token(self, dummy_keyring, tokens):
@@ -100,9 +98,14 @@ class TestKeyringStore:
             assert t is not None
             assert t.name == token.name
             assert t.token == token.token
-            assert t.book_id == token.book_id
+            if isinstance(t, BookToken):
+                assert t.book_id == token.book_id
             assert t.deployment_url == token.deployment_url
 
+        # Test not found
+        t = keyring_store.get_token("nonexistent", dummy_keyring)
+        assert t is None
+
     def test_remove_token(self, dummy_keyring, tokens):
         for token in tokens:
             keyring_store.save_token(token, dummy_keyring)
@@ -139,9 +142,26 @@ class TestKeyringStore:
                 keyring_store.save_token(token, dummy_keyring)
 
 
+class TestGeneralStore:
+    @pytest.fixture(autouse=True)
+    def setup(self, dummy_keyring, config_file, tokens):
+        for token in tokens:
+            keyring_store.save_token(token, dummy_keyring)
+
+        self.dummy_keyring = dummy_keyring
+        self.config_file = config_file[0]
+        self.tokens = list(tokens) + config_file[1]
+
+        yield
+
+    def test_get_all_tokens(self):
+        tokens, sources = get_all_tokens(self.dummy_keyring, [self.config_file])
+        assert len(tokens) == len(self.tokens)
+
+
 class TestToken:
     def test_create_token(self):
-        token = Token("test", 123, "asd")
+        token = BookToken.from_unsafe("test", "asd", 123)
 
         assert token.name == "test"
         assert token.book_id == 123
@@ -149,20 +169,56 @@ class TestToken:
         assert isinstance(token.deployment_url, str)
 
     def test_create_with_deployment_url(self):
-        token = Token("test", 123, "asd", Token.deployment_url)
-        assert token.deployment_url == Token.deployment_url
+        token = BookToken.from_unsafe("test", "asd", 123, BookToken.deployment_url)
+        assert token.deployment_url == BookToken.deployment_url
 
-    def test_from_unsafe(self, monkeypatch):
-        Token.deployment_url = "https://test.de"
+    def test_from_unsafe_book(self, monkeypatch):
+        BookToken.deployment_url = "https://test.de"
         monkeypatch.setattr(
             "snip.token.token.DEFAULT_DEPLOYMENT_URL", "https://test.de"
         )
 
-        token = Token.from_unsafe("test", "123", "asd")
-        assert token.deployment_url == Token.deployment_url
+        token = BookToken.from_unsafe(
+            name="test",
+            token="asd",
+            book_id="123",
+        )
+        assert token.deployment_url == BookToken.deployment_url
 
-        token = Token.from_unsafe("test", "123", "asd", None)
-        assert token.deployment_url == Token.deployment_url
+        token = BookToken.from_unsafe(
+            name="test",
+            book_id="123",
+            token="asd",
+            deployment_url=None,
+        )
+        assert token.deployment_url == BookToken.deployment_url
 
-        token = Token.from_unsafe("test", "123", "asd", Token.deployment_url)
-        assert token.deployment_url == Token.deployment_url
+        token = BookToken.from_unsafe(
+            name="test",
+            book_id="123",
+            token="asd",
+            deployment_url=BookToken.deployment_url,
+        )
+        assert token.deployment_url == BookToken.deployment_url
+        assert token.type == "book"
+
+    def test_from_unsafe_account(self):
+        token = AccountToken.from_unsafe("test", "asd")
+        assert token.name == "test"
+        assert token.token == "asd"
+        assert isinstance(token.deployment_url, str)
+        assert token.type == "account"
+
+    def test_repr(self):
+        token = BookToken.from_unsafe("test", "asd", 123)
+        r = repr(token)
+        assert "BookToken" in r
+        assert "test" in r
+        assert "123" in r
+        assert "https://" in r
+
+        token = AccountToken.from_unsafe("test", "asd")
+        r = repr(token)
+        assert "AccountToken" in r
+        assert "test" in r
+        assert "https://" in r
